==> jquery-responsive-font-sizes-1.0.4.tgz: package/index.js <==
;(function($) {
    $.responsiveFonts = function(elements) {
        for(var element in elements) {
            var currentElement = elements[element];
            var selector = currentElement.selector,
                element = currentElement.element,
                factor = currentElement.factor,
                useContainerWidth = currentElement.useContainerWidth;
            setNewCss(selector, element, factor, useContainerWidth);
        };
        function containerHeight(container) {
            return parseInt($(container).css('height'));
        };
        function containerWidth(container) {
            return parseInt($(container).css('width'));
        };
        function setNewCss(selector, element, factor, useContainerWidth) {
            var dimension = useContainerWidth ? containerWidth(selector) : containerHeight(selector);
            var newFontSize = calcPixelValue(dimension, factor);
            var newCssString = generateNewCssString(element, newFontSize);
            setNewInlineCss(element, newCssString);
        };
        function calcPixelValue(dimension, factor) {
            return dimension * factor;
        };
        function generateNewCssString(element, pixelValue) {
            var currentInlineStyle = getCurrentInlineStyle(element);
            return currentInlineStyle + '; font-size: ' + pixelValue + 'px;';
        };
        function setNewInlineCss(element, styleString){
            $(element).css('cssText', styleString);
        };
        function getCurrentInlineStyle(element) {
            var currentInlineStyle = $(element).attr("style");
            return (currentInlineStyle === undefined) ? '' : currentInlineStyle;
        };
    };
}(window.jQuery));

==> jquery-responsive-font-sizes-1.0.91.tgz: package/index.js <==
;(function($) {
    $.responsiveFonts = function(elements) {
        for(var element in elements) {
            var currentElement = elements[element];
            var selector = currentElement.selector,
                element = currentElement.element,
                factor = currentElement.factor,
                useContainerWidth = currentElement.useContainerWidth;
                property = currentElement.property;
            setNewCss(selector, element, factor, useContainerWidth, property);
        };
        function containerHeight(container) {
            return parseInt($(container).css('height'));
        };
        function containerWidth(container) {
            return parseInt($(container).css('width'));
        };
        function setNewCss(selector, element, factor, useContainerWidth, property) {
            var dimension = useContainerWidth ? containerWidth(selector) : containerHeight(selector);
            var newFontSize = calcPixelValue(dimension, factor);
            var newCssString = generateNewCssString(element, newFontSize, property);
            setNewInlineCss(element, newCssString);
        };
        function calcPixelValue(dimension, factor) {
            return dimension * factor;
        };
        function generateNewCssString(element, pixelValue, prop) {
            var currentInlineStyle = getCurrentInlineStyle(element);
            var prop = prop || 'font-size';
            prop += ': ';
            return currentInlineStyle + ';' + prop + pixelValue + 'px;';
        };
        function setNewInlineCss(element, styleString){
            $(element).css('cssText', styleString);
        };
        function getCurrentInlineStyle(element) {
            var currentInlineStyle = $(element).attr("style");
            return (currentInlineStyle === undefined) ? '' : currentInlineStyle;
        };
    };
}(window.jQuery));
